@@ -486,6 +486,11 @@ class opensshStatus(StatusMenuItem):
     def sshAllUsers(self):
         self.sshConnected = int(getoutput("netstat -t | grep -cE :ssh[[:space:]]*E{0}.*ESTABLISHED"))
         sshNetstat = getoutput("netstat -t | grep :ssh.*ESTABLISHED").split("\n")
+        try:
+            if not "ESTABLISHED" in sshNetstat[0]:
+                sshNetstat = []
+        except:
+            pass
         
         countInWLAN = 0
         countOutWLAN = 0
@@ -1073,6 +1078,11 @@ class opensshStatus(StatusMenuItem):
     def sshCountAll(self, dummy):
         self.sshUsers()
         sshNetstat = getoutput("netstat -t | grep :ssh.*ESTABLISHED").split("\n")
+        try:
+            if not "ESTABLISHED" in sshNetstat[0]:
+                sshNetstat = []
+        except:
+            pass
         
         countInWLAN = 0
         countOutWLAN = 0
@@ -1122,6 +1132,10 @@ class opensshStatus(StatusMenuItem):
             
         countInOther = self.sshConnected - countInWLAN - countInUSB
         countOutOther = len(sshNetstat) - self.sshConnected - countOutWLAN - countOutUSB
+        if countInOther < 0:
+            countInOther = 0
+        if countOutOther < 0:
+            countOutOther = 0
         self.labelCountInOther = countInOther
         self.labelCountOutOther = countOutOther
         
